@@ -15,6 +15,8 @@
  *  the sample application for demonstrating the use of the CTAXT interface
  *
  *  13.12.1993   hp      1st version
+ *  14.01.1994   hp      Fixed some bugs of incorrect casts like
+ *                        (Tcl_CmdProc) proc --> (Tcl_CmdProc *) proc
  */
 
 
@@ -60,8 +62,8 @@ extendTcl (interp,tkwin,clientData)
 {
   Tcl_CreateCommand (interp,
 		     "tkerror",
-		     (Tcl_CmdProc) handleTkBackgroundError,
+		     (Tcl_CmdProc *) handleTkBackgroundError,
 		     (ClientData) NULL,
-		     (Tcl_CmdDeleteProc) NULL);
+		     (Tcl_CmdDeleteProc *) NULL);
   return (0);
 }
